# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    CalendarAttendeeResponseStatus,
    CalendarEventStatus,
    CalendarEventVisibility,
    CalendarRecurrencePattern,
    CalendarReminderMethod,
    ContentTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    MailImportance,
    MailPriority,
    MailSensitivity,
    OrientationTypes,
    TextRoles,
)


class QueryContents(BaseModel):
    contents: Optional["QueryContentsContents"]


class QueryContentsContents(BaseModel):
    results: Optional[List[Optional["QueryContentsContentsResults"]]]


class QueryContentsContentsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryContentsContentsResultsOwner"
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    finished_date: Optional[Any] = Field(alias="finishedDate")
    workflow_duration: Optional[Any] = Field(alias="workflowDuration")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    address: Optional["QueryContentsContentsResultsAddress"]
    location: Optional["QueryContentsContentsResultsLocation"]
    features: Optional[str]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    relative_folder_path: Optional[str] = Field(alias="relativeFolderPath")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    quotes: Optional[List[str]]
    video: Optional["QueryContentsContentsResultsVideo"]
    audio: Optional["QueryContentsContentsResultsAudio"]
    image: Optional["QueryContentsContentsResultsImage"]
    document: Optional["QueryContentsContentsResultsDocument"]
    email: Optional["QueryContentsContentsResultsEmail"]
    event: Optional["QueryContentsContentsResultsEvent"]
    issue: Optional["QueryContentsContentsResultsIssue"]
    message: Optional["QueryContentsContentsResultsMessage"]
    post: Optional["QueryContentsContentsResultsPost"]
    package: Optional["QueryContentsContentsResultsPackage"]
    language: Optional["QueryContentsContentsResultsLanguage"]
    feed: Optional["QueryContentsContentsResultsFeed"]
    workflow: Optional["QueryContentsContentsResultsWorkflow"]
    pages: Optional[List["QueryContentsContentsResultsPages"]]
    segments: Optional[List["QueryContentsContentsResultsSegments"]]
    frames: Optional[List["QueryContentsContentsResultsFrames"]]
    error: Optional[str]


class QueryContentsContentsResultsOwner(BaseModel):
    id: str


class QueryContentsContentsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryContentsContentsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryContentsContentsResultsVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class QueryContentsContentsResultsAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class QueryContentsContentsResultsImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class QueryContentsContentsResultsDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    last_modified_by: Optional[str] = Field(alias="lastModifiedBy")
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class QueryContentsContentsResultsEmail(BaseModel):
    identifier: Optional[str]
    thread_identifier: Optional[str] = Field(alias="threadIdentifier")
    subject: Optional[str]
    labels: Optional[List[Optional[str]]]
    sensitivity: Optional[MailSensitivity]
    priority: Optional[MailPriority]
    importance: Optional[MailImportance]
    unsubscribe_url: Optional[str] = Field(alias="unsubscribeUrl")
    publication_name: Optional[str] = Field(alias="publicationName")
    publication_url: Optional[str] = Field(alias="publicationUrl")
    attachment_count: Optional[int] = Field(alias="attachmentCount")
    from_: Optional[List[Optional["QueryContentsContentsResultsEmailFrom"]]] = Field(
        alias="from"
    )
    to: Optional[List[Optional["QueryContentsContentsResultsEmailTo"]]]
    cc: Optional[List[Optional["QueryContentsContentsResultsEmailCc"]]]
    bcc: Optional[List[Optional["QueryContentsContentsResultsEmailBcc"]]]


class QueryContentsContentsResultsEmailFrom(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEmailTo(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEmailCc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEmailBcc(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsEvent(BaseModel):
    event_identifier: Optional[str] = Field(alias="eventIdentifier")
    calendar_identifier: Optional[str] = Field(alias="calendarIdentifier")
    subject: Optional[str]
    start_date_time: Optional[Any] = Field(alias="startDateTime")
    end_date_time: Optional[Any] = Field(alias="endDateTime")
    is_all_day: Optional[bool] = Field(alias="isAllDay")
    timezone: Optional[str]
    status: Optional[CalendarEventStatus]
    visibility: Optional[CalendarEventVisibility]
    meeting_link: Optional[str] = Field(alias="meetingLink")
    organizer: Optional["QueryContentsContentsResultsEventOrganizer"]
    attendees: Optional[List[Optional["QueryContentsContentsResultsEventAttendees"]]]
    categories: Optional[List[Optional[str]]]
    reminders: Optional[List[Optional["QueryContentsContentsResultsEventReminders"]]]
    recurrence: Optional["QueryContentsContentsResultsEventRecurrence"]
    recurring_event_identifier: Optional[str] = Field(alias="recurringEventIdentifier")
    is_recurring: Optional[bool] = Field(alias="isRecurring")


class QueryContentsContentsResultsEventOrganizer(BaseModel):
    name: Optional[str]
    email: Optional[str]
    is_optional: Optional[bool] = Field(alias="isOptional")
    is_organizer: Optional[bool] = Field(alias="isOrganizer")
    response_status: Optional[CalendarAttendeeResponseStatus] = Field(
        alias="responseStatus"
    )


class QueryContentsContentsResultsEventAttendees(BaseModel):
    name: Optional[str]
    email: Optional[str]
    is_optional: Optional[bool] = Field(alias="isOptional")
    is_organizer: Optional[bool] = Field(alias="isOrganizer")
    response_status: Optional[CalendarAttendeeResponseStatus] = Field(
        alias="responseStatus"
    )


class QueryContentsContentsResultsEventReminders(BaseModel):
    minutes_before: Optional[int] = Field(alias="minutesBefore")
    method: Optional[CalendarReminderMethod]


class QueryContentsContentsResultsEventRecurrence(BaseModel):
    pattern: Optional[CalendarRecurrencePattern]
    interval: Optional[int]
    count: Optional[int]
    until: Optional[Any]
    days_of_week: Optional[List[Optional[str]]] = Field(alias="daysOfWeek")
    day_of_month: Optional[int] = Field(alias="dayOfMonth")
    month_of_year: Optional[int] = Field(alias="monthOfYear")


class QueryContentsContentsResultsIssue(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    project: Optional[str]
    team: Optional[str]
    status: Optional[str]
    priority: Optional[str]
    type: Optional[str]
    labels: Optional[List[Optional[str]]]


class QueryContentsContentsResultsMessage(BaseModel):
    identifier: Optional[str]
    conversation_identifier: Optional[str] = Field(alias="conversationIdentifier")
    channel_identifier: Optional[str] = Field(alias="channelIdentifier")
    channel_name: Optional[str] = Field(alias="channelName")
    attachment_count: Optional[int] = Field(alias="attachmentCount")
    links: Optional[List[Optional[Any]]]
    author: Optional["QueryContentsContentsResultsMessageAuthor"]
    mentions: Optional[List[Optional["QueryContentsContentsResultsMessageMentions"]]]


class QueryContentsContentsResultsMessageAuthor(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsMessageMentions(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsPost(BaseModel):
    identifier: Optional[str]
    title: Optional[str]
    author: Optional["QueryContentsContentsResultsPostAuthor"]
    upvotes: Optional[int]
    downvotes: Optional[int]
    comment_count: Optional[int] = Field(alias="commentCount")
    links: Optional[List[Optional[Any]]]


class QueryContentsContentsResultsPostAuthor(BaseModel):
    name: Optional[str]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")


class QueryContentsContentsResultsPackage(BaseModel):
    file_count: Optional[int] = Field(alias="fileCount")
    folder_count: Optional[int] = Field(alias="folderCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")


class QueryContentsContentsResultsLanguage(BaseModel):
    languages: Optional[List[Optional[str]]]


class QueryContentsContentsResultsFeed(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryContentsContentsResultsPages(BaseModel):
    index: Optional[int]
    text: Optional[str]
    relevance: Optional[float]
    images: Optional[List[Optional["QueryContentsContentsResultsPagesImages"]]]
    chunks: Optional[List[Optional["QueryContentsContentsResultsPagesChunks"]]]


class QueryContentsContentsResultsPagesImages(BaseModel):
    id: Optional[str]
    mime_type: Optional[str] = Field(alias="mimeType")
    data: Optional[str]
    left: Optional[int]
    right: Optional[int]
    top: Optional[int]
    bottom: Optional[int]


class QueryContentsContentsResultsPagesChunks(BaseModel):
    index: Optional[int]
    page_index: Optional[int] = Field(alias="pageIndex")
    row_index: Optional[int] = Field(alias="rowIndex")
    column_index: Optional[int] = Field(alias="columnIndex")
    confidence: Optional[float]
    text: Optional[str]
    role: Optional[TextRoles]
    language: Optional[str]
    relevance: Optional[float]


class QueryContentsContentsResultsSegments(BaseModel):
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    text: Optional[str]
    relevance: Optional[float]


class QueryContentsContentsResultsFrames(BaseModel):
    index: Optional[int]
    description: Optional[str]
    text: Optional[str]
    relevance: Optional[float]


QueryContents.model_rebuild()
QueryContentsContents.model_rebuild()
QueryContentsContentsResults.model_rebuild()
QueryContentsContentsResultsEmail.model_rebuild()
QueryContentsContentsResultsEvent.model_rebuild()
QueryContentsContentsResultsMessage.model_rebuild()
QueryContentsContentsResultsPost.model_rebuild()
QueryContentsContentsResultsPages.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, ModelServiceTypes, SpecificationTypes


class UpdateSpecification(BaseModel):
    update_specification: Optional["UpdateSpecificationUpdateSpecification"] = Field(
        alias="updateSpecification"
    )


class UpdateSpecificationUpdateSpecification(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[SpecificationTypes]
    service_type: Optional[ModelServiceTypes] = Field(alias="serviceType")


UpdateSpecification.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllSpecifications(BaseModel):
    delete_all_specifications: Optional[
        List[Optional["DeleteAllSpecificationsDeleteAllSpecifications"]]
    ] = Field(alias="deleteAllSpecifications")


class DeleteAllSpecificationsDeleteAllSpecifications(BaseModel):
    id: str
    state: EntityState


DeleteAllSpecifications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalContraindication(BaseModel):
    update_medical_contraindication: Optional[
        "UpdateMedicalContraindicationUpdateMedicalContraindication"
    ] = Field(alias="updateMedicalContraindication")


class UpdateMedicalContraindicationUpdateMedicalContraindication(BaseModel):
    id: str
    name: str


UpdateMedicalContraindication.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBoxFolders(BaseModel):
    box_folders: Optional["QueryBoxFoldersBoxFolders"] = Field(alias="boxFolders")


class QueryBoxFoldersBoxFolders(BaseModel):
    results: Optional[List[Optional["QueryBoxFoldersBoxFoldersResults"]]]


class QueryBoxFoldersBoxFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QueryBoxFolders.model_rebuild()
QueryBoxFoldersBoxFolders.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalCondition(BaseModel):
    create_medical_condition: Optional[
        "CreateMedicalConditionCreateMedicalCondition"
    ] = Field(alias="createMedicalCondition")


class CreateMedicalConditionCreateMedicalCondition(BaseModel):
    id: str
    name: str


CreateMedicalCondition.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountSoftwares(BaseModel):
    count_softwares: Optional["CountSoftwaresCountSoftwares"] = Field(
        alias="countSoftwares"
    )


class CountSoftwaresCountSoftwares(BaseModel):
    count: Optional[Any]


CountSoftwares.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AssemblyAIModels,
    AzureDocumentIntelligenceModels,
    AzureDocumentIntelligenceVersions,
    ContentClassificationServiceTypes,
    ContentIndexingServiceTypes,
    ContentTypes,
    DeepgramModels,
    EmbeddingTypes,
    EntityEnrichmentServiceTypes,
    EntityExtractionServiceTypes,
    EntityState,
    FilePreparationServiceTypes,
    FileTypes,
    IntegrationServiceTypes,
    LinkTypes,
    MCPServerTypes,
    ObservableTypes,
    ReductoEnrichmentModes,
    ReductoExtractionModes,
    ReductoOcrModes,
    ReductoOcrSystems,
    RegexSourceTypes,
    StoragePolicyTypes,
    SummarizationTypes,
)


class QueryWorkflows(BaseModel):
    workflows: Optional["QueryWorkflowsWorkflows"]


class QueryWorkflowsWorkflows(BaseModel):
    results: Optional[List["QueryWorkflowsWorkflowsResults"]]


class QueryWorkflowsWorkflowsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryWorkflowsWorkflowsResultsOwner"
    state: EntityState
    ingestion: Optional["QueryWorkflowsWorkflowsResultsIngestion"]
    indexing: Optional["QueryWorkflowsWorkflowsResultsIndexing"]
    preparation: Optional["QueryWorkflowsWorkflowsResultsPreparation"]
    extraction: Optional["QueryWorkflowsWorkflowsResultsExtraction"]
    classification: Optional["QueryWorkflowsWorkflowsResultsClassification"]
    enrichment: Optional["QueryWorkflowsWorkflowsResultsEnrichment"]
    storage: Optional["QueryWorkflowsWorkflowsResultsStorage"]
    actions: Optional[List[Optional["QueryWorkflowsWorkflowsResultsActions"]]]


class QueryWorkflowsWorkflowsResultsOwner(BaseModel):
    id: str


class QueryWorkflowsWorkflowsResultsIngestion(BaseModel):
    if_: Optional["QueryWorkflowsWorkflowsResultsIngestionIf"] = Field(alias="if")
    collections: Optional[
        List[Optional["QueryWorkflowsWorkflowsResultsIngestionCollections"]]
    ]
    observations: Optional[
        List[Optional["QueryWorkflowsWorkflowsResultsIngestionObservations"]]
    ]
    enable_email_collections: Optional[bool] = Field(alias="enableEmailCollections")
    enable_folder_collections: Optional[bool] = Field(alias="enableFolderCollections")
    enable_message_collections: Optional[bool] = Field(alias="enableMessageCollections")


class QueryWorkflowsWorkflowsResultsIngestionIf(BaseModel):
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")


class QueryWorkflowsWorkflowsResultsIngestionCollections(BaseModel):
    id: str


class QueryWorkflowsWorkflowsResultsIngestionObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryWorkflowsWorkflowsResultsIngestionObservationsObservable"


class QueryWorkflowsWorkflowsResultsIngestionObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryWorkflowsWorkflowsResultsIndexing(BaseModel):
    jobs: Optional[List[Optional["QueryWorkflowsWorkflowsResultsIndexingJobs"]]]


class QueryWorkflowsWorkflowsResultsIndexingJobs(BaseModel):
    connector: Optional["QueryWorkflowsWorkflowsResultsIndexingJobsConnector"]


class QueryWorkflowsWorkflowsResultsIndexingJobsConnector(BaseModel):
    type: Optional[ContentIndexingServiceTypes]
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")


class QueryWorkflowsWorkflowsResultsPreparation(BaseModel):
    enable_unblocked_capture: Optional[bool] = Field(alias="enableUnblockedCapture")
    disable_smart_capture: Optional[bool] = Field(alias="disableSmartCapture")
    summarizations: Optional[
        List[Optional["QueryWorkflowsWorkflowsResultsPreparationSummarizations"]]
    ]
    jobs: Optional[List[Optional["QueryWorkflowsWorkflowsResultsPreparationJobs"]]]


class QueryWorkflowsWorkflowsResultsPreparationSummarizations(BaseModel):
    type: SummarizationTypes
    specification: Optional[
        "QueryWorkflowsWorkflowsResultsPreparationSummarizationsSpecification"
    ]
    tokens: Optional[int]
    items: Optional[int]
    prompt: Optional[str]


class QueryWorkflowsWorkflowsResultsPreparationSummarizationsSpecification(BaseModel):
    id: str


class QueryWorkflowsWorkflowsResultsPreparationJobs(BaseModel):
    connector: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnector"]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnector(BaseModel):
    type: FilePreparationServiceTypes
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    azure_document: Optional[
        "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorAzureDocument"
    ] = Field(alias="azureDocument")
    deepgram: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDeepgram"]
    assembly_ai: Optional[
        "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorAssemblyAi"
    ] = Field(alias="assemblyAI")
    page: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnectorPage"]
    document: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDocument"]
    email: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnectorEmail"]
    model_document: Optional[
        "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocument"
    ] = Field(alias="modelDocument")
    reducto: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnectorReducto"]
    mistral: Optional["QueryWorkflowsWorkflowsResultsPreparationJobsConnectorMistral"]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorAzureDocument(BaseModel):
    version: Optional[AzureDocumentIntelligenceVersions]
    model: Optional[AzureDocumentIntelligenceModels]
    endpoint: Optional[Any]
    key: Optional[str]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDeepgram(BaseModel):
    model: Optional[DeepgramModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorAssemblyAi(BaseModel):
    model: Optional[AssemblyAIModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorPage(BaseModel):
    enable_screenshot: Optional[bool] = Field(alias="enableScreenshot")


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorDocument(BaseModel):
    include_images: Optional[bool] = Field(alias="includeImages")


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorEmail(BaseModel):
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocument(BaseModel):
    specification: Optional[
        "QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocumentSpecification"
    ]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocumentSpecification(
    BaseModel
):
    id: str


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorReducto(BaseModel):
    ocr_mode: Optional[ReductoOcrModes] = Field(alias="ocrMode")
    ocr_system: Optional[ReductoOcrSystems] = Field(alias="ocrSystem")
    extraction_mode: Optional[ReductoExtractionModes] = Field(alias="extractionMode")
    enable_enrichment: Optional[bool] = Field(alias="enableEnrichment")
    enrichment_mode: Optional[ReductoEnrichmentModes] = Field(alias="enrichmentMode")
    key: Optional[str]


class QueryWorkflowsWorkflowsResultsPreparationJobsConnectorMistral(BaseModel):
    key: Optional[str]


class QueryWorkflowsWorkflowsResultsExtraction(BaseModel):
    jobs: Optional[List[Optional["QueryWorkflowsWorkflowsResultsExtractionJobs"]]]


class QueryWorkflowsWorkflowsResultsExtractionJobs(BaseModel):
    connector: Optional["QueryWorkflowsWorkflowsResultsExtractionJobsConnector"]


class QueryWorkflowsWorkflowsResultsExtractionJobsConnector(BaseModel):
    type: EntityExtractionServiceTypes
    content_types: Optional[List[ContentTypes]] = Field(alias="contentTypes")
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    extracted_types: Optional[List[ObservableTypes]] = Field(alias="extractedTypes")
    extracted_count: Optional[int] = Field(alias="extractedCount")
    azure_text: Optional[
        "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureText"
    ] = Field(alias="azureText")
    azure_image: Optional[
        "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureImage"
    ] = Field(alias="azureImage")
    model_image: Optional[
        "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImage"
    ] = Field(alias="modelImage")
    model_text: Optional[
        "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelText"
    ] = Field(alias="modelText")


class QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureText(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")
    enable_pii: Optional[bool] = Field(alias="enablePII")


class QueryWorkflowsWorkflowsResultsExtractionJobsConnectorAzureImage(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")


class QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImage(BaseModel):
    specification: Optional[
        "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImageSpecification"
    ]


class QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImageSpecification(
    BaseModel
):
    id: str


class QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelText(BaseModel):
    specification: Optional[
        "QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelTextSpecification"
    ]
    token_threshold: Optional[int] = Field(alias="tokenThreshold")


class QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelTextSpecification(
    BaseModel
):
    id: str


class QueryWorkflowsWorkflowsResultsClassification(BaseModel):
    jobs: Optional[List[Optional["QueryWorkflowsWorkflowsResultsClassificationJobs"]]]


class QueryWorkflowsWorkflowsResultsClassificationJobs(BaseModel):
    connector: Optional["QueryWorkflowsWorkflowsResultsClassificationJobsConnector"]


class QueryWorkflowsWorkflowsResultsClassificationJobsConnector(BaseModel):
    type: ContentClassificationServiceTypes
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")
    model: Optional["QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModel"]
    regex: Optional["QueryWorkflowsWorkflowsResultsClassificationJobsConnectorRegex"]


class QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModel(BaseModel):
    specification: Optional[
        "QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModelSpecification"
    ]
    rules: Optional[
        List[
            Optional[
                "QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModelRules"
            ]
        ]
    ]


class QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModelSpecification(
    BaseModel
):
    id: str


class QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModelRules(BaseModel):
    then: Optional[str]
    if_: Optional[str] = Field(alias="if")


class QueryWorkflowsWorkflowsResultsClassificationJobsConnectorRegex(BaseModel):
    rules: Optional[
        List[
            Optional[
                "QueryWorkflowsWorkflowsResultsClassificationJobsConnectorRegexRules"
            ]
        ]
    ]


class QueryWorkflowsWorkflowsResultsClassificationJobsConnectorRegexRules(BaseModel):
    then: Optional[str]
    type: Optional[RegexSourceTypes]
    path: Optional[str]
    matches: Optional[str]


class QueryWorkflowsWorkflowsResultsEnrichment(BaseModel):
    link: Optional["QueryWorkflowsWorkflowsResultsEnrichmentLink"]
    jobs: Optional[List[Optional["QueryWorkflowsWorkflowsResultsEnrichmentJobs"]]]


class QueryWorkflowsWorkflowsResultsEnrichmentLink(BaseModel):
    enable_crawling: Optional[bool] = Field(alias="enableCrawling")
    allowed_domains: Optional[List[str]] = Field(alias="allowedDomains")
    excluded_domains: Optional[List[str]] = Field(alias="excludedDomains")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")
    allowed_links: Optional[List[LinkTypes]] = Field(alias="allowedLinks")
    excluded_links: Optional[List[LinkTypes]] = Field(alias="excludedLinks")
    allowed_files: Optional[List[FileTypes]] = Field(alias="allowedFiles")
    excluded_files: Optional[List[FileTypes]] = Field(alias="excludedFiles")
    allowed_content_types: Optional[List[ContentTypes]] = Field(
        alias="allowedContentTypes"
    )
    excluded_content_types: Optional[List[ContentTypes]] = Field(
        alias="excludedContentTypes"
    )
    allow_content_domain: Optional[bool] = Field(alias="allowContentDomain")
    maximum_links: Optional[int] = Field(alias="maximumLinks")


class QueryWorkflowsWorkflowsResultsEnrichmentJobs(BaseModel):
    connector: Optional["QueryWorkflowsWorkflowsResultsEnrichmentJobsConnector"]


class QueryWorkflowsWorkflowsResultsEnrichmentJobsConnector(BaseModel):
    type: Optional[EntityEnrichmentServiceTypes]
    enriched_types: Optional[List[Optional[ObservableTypes]]] = Field(
        alias="enrichedTypes"
    )
    fhir: Optional["QueryWorkflowsWorkflowsResultsEnrichmentJobsConnectorFhir"]
    diffbot: Optional["QueryWorkflowsWorkflowsResultsEnrichmentJobsConnectorDiffbot"]


class QueryWorkflowsWorkflowsResultsEnrichmentJobsConnectorFhir(BaseModel):
    endpoint: Optional[Any]


class QueryWorkflowsWorkflowsResultsEnrichmentJobsConnectorDiffbot(BaseModel):
    key: Optional[Any]


class QueryWorkflowsWorkflowsResultsStorage(BaseModel):
    policy: Optional["QueryWorkflowsWorkflowsResultsStoragePolicy"]


class QueryWorkflowsWorkflowsResultsStoragePolicy(BaseModel):
    type: Optional[StoragePolicyTypes]
    allow_duplicates: Optional[bool] = Field(alias="allowDuplicates")
    embedding_types: Optional[List[Optional[EmbeddingTypes]]] = Field(
        alias="embeddingTypes"
    )


class QueryWorkflowsWorkflowsResultsActions(BaseModel):
    connector: Optional["QueryWorkflowsWorkflowsResultsActionsConnector"]


class QueryWorkflowsWorkflowsResultsActionsConnector(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["QueryWorkflowsWorkflowsResultsActionsConnectorSlack"]
    email: Optional["QueryWorkflowsWorkflowsResultsActionsConnectorEmail"]
    twitter: Optional["QueryWorkflowsWorkflowsResultsActionsConnectorTwitter"]
    mcp: Optional["QueryWorkflowsWorkflowsResultsActionsConnectorMcp"]


class QueryWorkflowsWorkflowsResultsActionsConnectorSlack(BaseModel):
    token: str
    channel: str


class QueryWorkflowsWorkflowsResultsActionsConnectorEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class QueryWorkflowsWorkflowsResultsActionsConnectorTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class QueryWorkflowsWorkflowsResultsActionsConnectorMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


QueryWorkflows.model_rebuild()
QueryWorkflowsWorkflows.model_rebuild()
QueryWorkflowsWorkflowsResults.model_rebuild()
QueryWorkflowsWorkflowsResultsIngestion.model_rebuild()
QueryWorkflowsWorkflowsResultsIngestionObservations.model_rebuild()
QueryWorkflowsWorkflowsResultsIndexing.model_rebuild()
QueryWorkflowsWorkflowsResultsIndexingJobs.model_rebuild()
QueryWorkflowsWorkflowsResultsPreparation.model_rebuild()
QueryWorkflowsWorkflowsResultsPreparationSummarizations.model_rebuild()
QueryWorkflowsWorkflowsResultsPreparationJobs.model_rebuild()
QueryWorkflowsWorkflowsResultsPreparationJobsConnector.model_rebuild()
QueryWorkflowsWorkflowsResultsPreparationJobsConnectorModelDocument.model_rebuild()
QueryWorkflowsWorkflowsResultsExtraction.model_rebuild()
QueryWorkflowsWorkflowsResultsExtractionJobs.model_rebuild()
QueryWorkflowsWorkflowsResultsExtractionJobsConnector.model_rebuild()
QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelImage.model_rebuild()
QueryWorkflowsWorkflowsResultsExtractionJobsConnectorModelText.model_rebuild()
QueryWorkflowsWorkflowsResultsClassification.model_rebuild()
QueryWorkflowsWorkflowsResultsClassificationJobs.model_rebuild()
QueryWorkflowsWorkflowsResultsClassificationJobsConnector.model_rebuild()
QueryWorkflowsWorkflowsResultsClassificationJobsConnectorModel.model_rebuild()
QueryWorkflowsWorkflowsResultsClassificationJobsConnectorRegex.model_rebuild()
QueryWorkflowsWorkflowsResultsEnrichment.model_rebuild()
QueryWorkflowsWorkflowsResultsEnrichmentJobs.model_rebuild()
QueryWorkflowsWorkflowsResultsEnrichmentJobsConnector.model_rebuild()
QueryWorkflowsWorkflowsResultsStorage.model_rebuild()
QueryWorkflowsWorkflowsResultsActions.model_rebuild()
QueryWorkflowsWorkflowsResultsActionsConnector.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountConnectors(BaseModel):
    count_connectors: Optional["CountConnectorsCountConnectors"] = Field(
        alias="countConnectors"
    )


class CountConnectorsCountConnectors(BaseModel):
    count: Optional[Any]


CountConnectors.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalGuidelines(BaseModel):
    delete_all_medical_guidelines: Optional[
        List[Optional["DeleteAllMedicalGuidelinesDeleteAllMedicalGuidelines"]]
    ] = Field(alias="deleteAllMedicalGuidelines")


class DeleteAllMedicalGuidelinesDeleteAllMedicalGuidelines(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalGuidelines.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSoftwares(BaseModel):
    delete_softwares: Optional[List[Optional["DeleteSoftwaresDeleteSoftwares"]]] = (
        Field(alias="deleteSoftwares")
    )


class DeleteSoftwaresDeleteSoftwares(BaseModel):
    id: str
    state: EntityState


DeleteSoftwares.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteUser(BaseModel):
    delete_user: Optional["DeleteUserDeleteUser"] = Field(alias="deleteUser")


class DeleteUserDeleteUser(BaseModel):
    id: str
    state: EntityState


DeleteUser.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ObservableTypes,
    OccurrenceTypes,
)


class IngestTextBatch(BaseModel):
    ingest_text_batch: Optional[List[Optional["IngestTextBatchIngestTextBatch"]]] = (
        Field(alias="ingestTextBatch")
    )


class IngestTextBatchIngestTextBatch(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    identifier: Optional[str]
    collections: Optional[List[Optional["IngestTextBatchIngestTextBatchCollections"]]]
    observations: Optional[List[Optional["IngestTextBatchIngestTextBatchObservations"]]]


class IngestTextBatchIngestTextBatchCollections(BaseModel):
    id: str
    name: str


class IngestTextBatchIngestTextBatchObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "IngestTextBatchIngestTextBatchObservationsObservable"
    related: Optional["IngestTextBatchIngestTextBatchObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[
        List[Optional["IngestTextBatchIngestTextBatchObservationsOccurrences"]]
    ]
    state: EntityState


class IngestTextBatchIngestTextBatchObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class IngestTextBatchIngestTextBatchObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class IngestTextBatchIngestTextBatchObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional[
        "IngestTextBatchIngestTextBatchObservationsOccurrencesBoundingBox"
    ] = Field(alias="boundingBox")


class IngestTextBatchIngestTextBatchObservationsOccurrencesBoundingBox(BaseModel):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


IngestTextBatch.model_rebuild()
IngestTextBatchIngestTextBatch.model_rebuild()
IngestTextBatchIngestTextBatchObservations.model_rebuild()
IngestTextBatchIngestTextBatchObservationsOccurrences.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteLabel(BaseModel):
    delete_label: Optional["DeleteLabelDeleteLabel"] = Field(alias="deleteLabel")


class DeleteLabelDeleteLabel(BaseModel):
    id: str
    state: EntityState


DeleteLabel.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalIndication(BaseModel):
    update_medical_indication: Optional[
        "UpdateMedicalIndicationUpdateMedicalIndication"
    ] = Field(alias="updateMedicalIndication")


class UpdateMedicalIndicationUpdateMedicalIndication(BaseModel):
    id: str
    name: str


UpdateMedicalIndication.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ArcadeProviders,
    AuthenticationServiceTypes,
    ConnectorTypes,
    EntityState,
    IntegrationServiceTypes,
    MCPServerTypes,
    OAuthProviders,
    UserTypes,
)


class GetUserByIdentifier(BaseModel):
    user_by_identifier: Optional["GetUserByIdentifierUserByIdentifier"] = Field(
        alias="userByIdentifier"
    )


class GetUserByIdentifierUserByIdentifier(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "GetUserByIdentifierUserByIdentifierOwner"
    state: EntityState
    type: Optional[UserTypes]
    identifier: str
    description: Optional[str]
    connectors: Optional[
        List[Optional["GetUserByIdentifierUserByIdentifierConnectors"]]
    ]


class GetUserByIdentifierUserByIdentifierOwner(BaseModel):
    id: str


class GetUserByIdentifierUserByIdentifierConnectors(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConnectorTypes]
    authentication: Optional[
        "GetUserByIdentifierUserByIdentifierConnectorsAuthentication"
    ]
    integration: Optional["GetUserByIdentifierUserByIdentifierConnectorsIntegration"]


class GetUserByIdentifierUserByIdentifierConnectorsAuthentication(BaseModel):
    type: AuthenticationServiceTypes
    microsoft: Optional[
        "GetUserByIdentifierUserByIdentifierConnectorsAuthenticationMicrosoft"
    ]
    google: Optional[
        "GetUserByIdentifierUserByIdentifierConnectorsAuthenticationGoogle"
    ]
    oauth: Optional["GetUserByIdentifierUserByIdentifierConnectorsAuthenticationOauth"]
    arcade: Optional[
        "GetUserByIdentifierUserByIdentifierConnectorsAuthenticationArcade"
    ]


class GetUserByIdentifierUserByIdentifierConnectorsAuthenticationMicrosoft(BaseModel):
    tenant_id: str = Field(alias="tenantId")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class GetUserByIdentifierUserByIdentifierConnectorsAuthenticationGoogle(BaseModel):
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class GetUserByIdentifierUserByIdentifierConnectorsAuthenticationOauth(BaseModel):
    refresh_token: str = Field(alias="refreshToken")
    provider: OAuthProviders
    metadata: Optional[str]


class GetUserByIdentifierUserByIdentifierConnectorsAuthenticationArcade(BaseModel):
    authorization_id: str = Field(alias="authorizationId")
    provider: ArcadeProviders
    metadata: Optional[str]


class GetUserByIdentifierUserByIdentifierConnectorsIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["GetUserByIdentifierUserByIdentifierConnectorsIntegrationSlack"]
    email: Optional["GetUserByIdentifierUserByIdentifierConnectorsIntegrationEmail"]
    twitter: Optional["GetUserByIdentifierUserByIdentifierConnectorsIntegrationTwitter"]
    mcp: Optional["GetUserByIdentifierUserByIdentifierConnectorsIntegrationMcp"]


class GetUserByIdentifierUserByIdentifierConnectorsIntegrationSlack(BaseModel):
    token: str
    channel: str


class GetUserByIdentifierUserByIdentifierConnectorsIntegrationEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class GetUserByIdentifierUserByIdentifierConnectorsIntegrationTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class GetUserByIdentifierUserByIdentifierConnectorsIntegrationMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


GetUserByIdentifier.model_rebuild()
GetUserByIdentifierUserByIdentifier.model_rebuild()
GetUserByIdentifierUserByIdentifierConnectors.model_rebuild()
GetUserByIdentifierUserByIdentifierConnectorsAuthentication.model_rebuild()
GetUserByIdentifierUserByIdentifierConnectorsIntegration.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryDiscordChannels(BaseModel):
    discord_channels: Optional["QueryDiscordChannelsDiscordChannels"] = Field(
        alias="discordChannels"
    )


class QueryDiscordChannelsDiscordChannels(BaseModel):
    results: Optional[List[Optional["QueryDiscordChannelsDiscordChannelsResults"]]]


class QueryDiscordChannelsDiscordChannelsResults(BaseModel):
    channel_name: Optional[str] = Field(alias="channelName")
    channel_id: Optional[str] = Field(alias="channelId")


QueryDiscordChannels.model_rebuild()
QueryDiscordChannelsDiscordChannels.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ObservableTypes,
    OccurrenceTypes,
)


class IngestEncodedFile(BaseModel):
    ingest_encoded_file: Optional["IngestEncodedFileIngestEncodedFile"] = Field(
        alias="ingestEncodedFile"
    )


class IngestEncodedFileIngestEncodedFile(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    identifier: Optional[str]
    collections: Optional[
        List[Optional["IngestEncodedFileIngestEncodedFileCollections"]]
    ]
    observations: Optional[
        List[Optional["IngestEncodedFileIngestEncodedFileObservations"]]
    ]


class IngestEncodedFileIngestEncodedFileCollections(BaseModel):
    id: str
    name: str


class IngestEncodedFileIngestEncodedFileObservations(BaseModel):
    id: str
    type: ObservableTypes
    observable: "IngestEncodedFileIngestEncodedFileObservationsObservable"
    related: Optional["IngestEncodedFileIngestEncodedFileObservationsRelated"]
    related_type: Optional[ObservableTypes] = Field(alias="relatedType")
    relation: Optional[str]
    occurrences: Optional[
        List[Optional["IngestEncodedFileIngestEncodedFileObservationsOccurrences"]]
    ]
    state: EntityState


class IngestEncodedFileIngestEncodedFileObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class IngestEncodedFileIngestEncodedFileObservationsRelated(BaseModel):
    id: str
    name: Optional[str]


class IngestEncodedFileIngestEncodedFileObservationsOccurrences(BaseModel):
    type: Optional[OccurrenceTypes]
    confidence: Optional[float]
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_index: Optional[int] = Field(alias="pageIndex")
    bounding_box: Optional[
        "IngestEncodedFileIngestEncodedFileObservationsOccurrencesBoundingBox"
    ] = Field(alias="boundingBox")


class IngestEncodedFileIngestEncodedFileObservationsOccurrencesBoundingBox(BaseModel):
    left: Optional[float]
    top: Optional[float]
    width: Optional[float]
    height: Optional[float]


IngestEncodedFile.model_rebuild()
IngestEncodedFileIngestEncodedFile.model_rebuild()
IngestEncodedFileIngestEncodedFileObservations.model_rebuild()
IngestEncodedFileIngestEncodedFileObservationsOccurrences.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMicrosoftCalendars(BaseModel):
    microsoft_calendars: Optional["QueryMicrosoftCalendarsMicrosoftCalendars"] = Field(
        alias="microsoftCalendars"
    )


class QueryMicrosoftCalendarsMicrosoftCalendars(BaseModel):
    results: Optional[
        List[Optional["QueryMicrosoftCalendarsMicrosoftCalendarsResults"]]
    ]


class QueryMicrosoftCalendarsMicrosoftCalendarsResults(BaseModel):
    calendar_name: Optional[str] = Field(alias="calendarName")
    calendar_id: Optional[str] = Field(alias="calendarId")


QueryMicrosoftCalendars.model_rebuild()
QueryMicrosoftCalendarsMicrosoftCalendars.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    EntityState,
    FileTypes,
    ImageProjectionTypes,
    OrientationTypes,
    TextTypes,
)


class PublishConversation(BaseModel):
    publish_conversation: Optional["PublishConversationPublishConversation"] = Field(
        alias="publishConversation"
    )


class PublishConversationPublishConversation(BaseModel):
    contents: Optional[List[Optional["PublishConversationPublishConversationContents"]]]
    details: Optional["PublishConversationPublishConversationDetails"]


class PublishConversationPublishConversationContents(BaseModel):
    id: str
    name: str
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    identifier: Optional[str]
    markdown: Optional[str]
    uri: Optional[Any]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    relative_folder_path: Optional[str] = Field(alias="relativeFolderPath")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[List[str]]
    bullets: Optional[List[str]]
    headlines: Optional[List[str]]
    posts: Optional[List[str]]
    chapters: Optional[List[str]]
    questions: Optional[List[str]]
    quotes: Optional[List[str]]
    video: Optional["PublishConversationPublishConversationContentsVideo"]
    audio: Optional["PublishConversationPublishConversationContentsAudio"]
    image: Optional["PublishConversationPublishConversationContentsImage"]
    document: Optional["PublishConversationPublishConversationContentsDocument"]


class PublishConversationPublishConversationContentsVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class PublishConversationPublishConversationContentsAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class PublishConversationPublishConversationContentsImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class PublishConversationPublishConversationContentsDocument(BaseModel):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    last_modified_by: Optional[str] = Field(alias="lastModifiedBy")
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class PublishConversationPublishConversationDetails(BaseModel):
    contents: Optional[List["PublishConversationPublishConversationDetailsContents"]]
    summaries: Optional[List[str]]
    text: Optional[str]
    text_type: Optional[TextTypes] = Field(alias="textType")
    summary_specification: Optional[str] = Field(alias="summarySpecification")
    publish_specification: Optional[str] = Field(alias="publishSpecification")
    summary_time: Optional[Any] = Field(alias="summaryTime")
    publish_time: Optional[Any] = Field(alias="publishTime")


class PublishConversationPublishConversationDetailsContents(BaseModel):
    id: str


PublishConversation.model_rebuild()
PublishConversationPublishConversation.model_rebuild()
PublishConversationPublishConversationContents.model_rebuild()
PublishConversationPublishConversationDetails.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalGuidelines(BaseModel):
    count_medical_guidelines: Optional[
        "CountMedicalGuidelinesCountMedicalGuidelines"
    ] = Field(alias="countMedicalGuidelines")


class CountMedicalGuidelinesCountMedicalGuidelines(BaseModel):
    count: Optional[Any]


CountMedicalGuidelines.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryNotionDatabases(BaseModel):
    notion_databases: Optional["QueryNotionDatabasesNotionDatabases"] = Field(
        alias="notionDatabases"
    )


class QueryNotionDatabasesNotionDatabases(BaseModel):
    results: Optional[List[Optional["QueryNotionDatabasesNotionDatabasesResults"]]]


class QueryNotionDatabasesNotionDatabasesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryNotionDatabases.model_rebuild()
QueryNotionDatabasesNotionDatabases.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGitHubRepositories(BaseModel):
    git_hub_repositories: Optional["QueryGitHubRepositoriesGitHubRepositories"] = Field(
        alias="gitHubRepositories"
    )


class QueryGitHubRepositoriesGitHubRepositories(BaseModel):
    results: Optional[
        List[Optional["QueryGitHubRepositoriesGitHubRepositoriesResults"]]
    ]


class QueryGitHubRepositoriesGitHubRepositoriesResults(BaseModel):
    repository_owner: Optional[str] = Field(alias="repositoryOwner")
    repository_name: Optional[str] = Field(alias="repositoryName")
    repository_full_name: Optional[str] = Field(alias="repositoryFullName")
    description: Optional[str]
    is_private: Optional[bool] = Field(alias="isPrivate")
    stargazers_count: Optional[int] = Field(alias="stargazersCount")
    forks_count: Optional[int] = Field(alias="forksCount")
    pushed_at: Optional[Any] = Field(alias="pushedAt")
    created_at: Optional[Any] = Field(alias="createdAt")
    is_owner: Optional[bool] = Field(alias="isOwner")
    language: Optional[str]


QueryGitHubRepositories.model_rebuild()
QueryGitHubRepositoriesGitHubRepositories.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AlertTypes,
    ContentPublishingServiceTypes,
    ContentTypes,
    ElevenLabsModels,
    EntityState,
    FileTypes,
    GoogleImageModels,
    IntegrationServiceTypes,
    MCPServerTypes,
    ObservableTypes,
    OpenAIImageModels,
    OpenAIVideoModels,
    TimedPolicyRecurrenceTypes,
    VideoSizeTypes,
)


class GetAlert(BaseModel):
    alert: Optional["GetAlertAlert"]


class GetAlertAlert(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "GetAlertAlertOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: AlertTypes
    summary_prompt: Optional[str] = Field(alias="summaryPrompt")
    publish_prompt: str = Field(alias="publishPrompt")
    view: Optional["GetAlertAlertView"]
    filter: Optional["GetAlertAlertFilter"]
    integration: "GetAlertAlertIntegration"
    publishing: "GetAlertAlertPublishing"
    summary_specification: Optional["GetAlertAlertSummarySpecification"] = Field(
        alias="summarySpecification"
    )
    publish_specification: Optional["GetAlertAlertPublishSpecification"] = Field(
        alias="publishSpecification"
    )
    schedule_policy: Optional["GetAlertAlertSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )
    last_alert_date: Optional[Any] = Field(alias="lastAlertDate")


class GetAlertAlertOwner(BaseModel):
    id: str


class GetAlertAlertView(BaseModel):
    id: str


class GetAlertAlertFilter(BaseModel):
    date_range: Optional["GetAlertAlertFilterDateRange"] = Field(alias="dateRange")
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["GetAlertAlertFilterCreationDateRange"] = Field(
        alias="creationDateRange"
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["GetAlertAlertFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["GetAlertAlertFilterSimilarContents"]] = Field(
        alias="similarContents"
    )
    contents: Optional[List["GetAlertAlertFilterContents"]]
    feeds: Optional[List["GetAlertAlertFilterFeeds"]]
    workflows: Optional[List["GetAlertAlertFilterWorkflows"]]
    collections: Optional[List["GetAlertAlertFilterCollections"]]
    users: Optional[List["GetAlertAlertFilterUsers"]]
    observations: Optional[List["GetAlertAlertFilterObservations"]]
    or_: Optional[List["GetAlertAlertFilterOr"]] = Field(alias="or")
    and_: Optional[List["GetAlertAlertFilterAnd"]] = Field(alias="and")
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")


class GetAlertAlertFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetAlertAlertFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetAlertAlertFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetAlertAlertFilterSimilarContents(BaseModel):
    id: str


class GetAlertAlertFilterContents(BaseModel):
    id: str


class GetAlertAlertFilterFeeds(BaseModel):
    id: str


class GetAlertAlertFilterWorkflows(BaseModel):
    id: str


class GetAlertAlertFilterCollections(BaseModel):
    id: str


class GetAlertAlertFilterUsers(BaseModel):
    id: str


class GetAlertAlertFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "GetAlertAlertFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetAlertAlertFilterObservationsObservable(BaseModel):
    id: str


class GetAlertAlertFilterOr(BaseModel):
    feeds: Optional[List["GetAlertAlertFilterOrFeeds"]]
    workflows: Optional[List["GetAlertAlertFilterOrWorkflows"]]
    collections: Optional[List["GetAlertAlertFilterOrCollections"]]
    users: Optional[List["GetAlertAlertFilterOrUsers"]]
    observations: Optional[List["GetAlertAlertFilterOrObservations"]]


class GetAlertAlertFilterOrFeeds(BaseModel):
    id: str


class GetAlertAlertFilterOrWorkflows(BaseModel):
    id: str


class GetAlertAlertFilterOrCollections(BaseModel):
    id: str


class GetAlertAlertFilterOrUsers(BaseModel):
    id: str


class GetAlertAlertFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "GetAlertAlertFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetAlertAlertFilterOrObservationsObservable(BaseModel):
    id: str


class GetAlertAlertFilterAnd(BaseModel):
    feeds: Optional[List["GetAlertAlertFilterAndFeeds"]]
    workflows: Optional[List["GetAlertAlertFilterAndWorkflows"]]
    collections: Optional[List["GetAlertAlertFilterAndCollections"]]
    users: Optional[List["GetAlertAlertFilterAndUsers"]]
    observations: Optional[List["GetAlertAlertFilterAndObservations"]]


class GetAlertAlertFilterAndFeeds(BaseModel):
    id: str


class GetAlertAlertFilterAndWorkflows(BaseModel):
    id: str


class GetAlertAlertFilterAndCollections(BaseModel):
    id: str


class GetAlertAlertFilterAndUsers(BaseModel):
    id: str


class GetAlertAlertFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "GetAlertAlertFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetAlertAlertFilterAndObservationsObservable(BaseModel):
    id: str


class GetAlertAlertIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["GetAlertAlertIntegrationSlack"]
    email: Optional["GetAlertAlertIntegrationEmail"]
    twitter: Optional["GetAlertAlertIntegrationTwitter"]
    mcp: Optional["GetAlertAlertIntegrationMcp"]


class GetAlertAlertIntegrationSlack(BaseModel):
    token: str
    channel: str


class GetAlertAlertIntegrationEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class GetAlertAlertIntegrationTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class GetAlertAlertIntegrationMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


class GetAlertAlertPublishing(BaseModel):
    type: ContentPublishingServiceTypes
    eleven_labs: Optional["GetAlertAlertPublishingElevenLabs"] = Field(
        alias="elevenLabs"
    )
    open_ai_image: Optional["GetAlertAlertPublishingOpenAiImage"] = Field(
        alias="openAIImage"
    )
    google_image: Optional["GetAlertAlertPublishingGoogleImage"] = Field(
        alias="googleImage"
    )
    open_ai_video: Optional["GetAlertAlertPublishingOpenAiVideo"] = Field(
        alias="openAIVideo"
    )


class GetAlertAlertPublishingElevenLabs(BaseModel):
    model: Optional[ElevenLabsModels]
    voice: Optional[str]


class GetAlertAlertPublishingOpenAiImage(BaseModel):
    model: Optional[OpenAIImageModels]
    count: Optional[int]
    seed: Optional["GetAlertAlertPublishingOpenAiImageSeed"]


class GetAlertAlertPublishingOpenAiImageSeed(BaseModel):
    id: str


class GetAlertAlertPublishingGoogleImage(BaseModel):
    model: Optional[GoogleImageModels]
    count: Optional[int]
    seed: Optional["GetAlertAlertPublishingGoogleImageSeed"]


class GetAlertAlertPublishingGoogleImageSeed(BaseModel):
    id: str


class GetAlertAlertPublishingOpenAiVideo(BaseModel):
    model: Optional[OpenAIVideoModels]
    seconds: Optional[int]
    size: Optional[VideoSizeTypes]
    seed: Optional["GetAlertAlertPublishingOpenAiVideoSeed"]


class GetAlertAlertPublishingOpenAiVideoSeed(BaseModel):
    id: str


class GetAlertAlertSummarySpecification(BaseModel):
    id: str


class GetAlertAlertPublishSpecification(BaseModel):
    id: str


class GetAlertAlertSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")
    cron: Optional[str]
    time_zone_id: Optional[str] = Field(alias="timeZoneId")


GetAlert.model_rebuild()
GetAlertAlert.model_rebuild()
GetAlertAlertFilter.model_rebuild()
GetAlertAlertFilterObservations.model_rebuild()
GetAlertAlertFilterOr.model_rebuild()
GetAlertAlertFilterOrObservations.model_rebuild()
GetAlertAlertFilterAnd.model_rebuild()
GetAlertAlertFilterAndObservations.model_rebuild()
GetAlertAlertIntegration.model_rebuild()
GetAlertAlertPublishing.model_rebuild()
GetAlertAlertPublishingOpenAiImage.model_rebuild()
GetAlertAlertPublishingGoogleImage.model_rebuild()
GetAlertAlertPublishingOpenAiVideo.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalGuideline(BaseModel):
    update_medical_guideline: Optional[
        "UpdateMedicalGuidelineUpdateMedicalGuideline"
    ] = Field(alias="updateMedicalGuideline")


class UpdateMedicalGuidelineUpdateMedicalGuideline(BaseModel):
    id: str
    name: str


UpdateMedicalGuideline.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalDevices(BaseModel):
    count_medical_devices: Optional["CountMedicalDevicesCountMedicalDevices"] = Field(
        alias="countMedicalDevices"
    )


class CountMedicalDevicesCountMedicalDevices(BaseModel):
    count: Optional[Any]


CountMedicalDevices.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryDiscordGuilds(BaseModel):
    discord_guilds: Optional["QueryDiscordGuildsDiscordGuilds"] = Field(
        alias="discordGuilds"
    )


class QueryDiscordGuildsDiscordGuilds(BaseModel):
    results: Optional[List[Optional["QueryDiscordGuildsDiscordGuildsResults"]]]


class QueryDiscordGuildsDiscordGuildsResults(BaseModel):
    guild_name: Optional[str] = Field(alias="guildName")
    guild_id: Optional[str] = Field(alias="guildId")


QueryDiscordGuilds.model_rebuild()
QueryDiscordGuildsDiscordGuilds.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryLinearProjects(BaseModel):
    linear_projects: Optional["QueryLinearProjectsLinearProjects"] = Field(
        alias="linearProjects"
    )


class QueryLinearProjectsLinearProjects(BaseModel):
    results: Optional[List[str]]


QueryLinearProjects.model_rebuild()
